

* ************************************************************
* PROGRAM: ATM_LongRun_PoolInd_2017_07_17
* PROGRAMMER: Simone Schaner
* PURPOSE: Main long run analysis, but pooling impact of 
*	husband and wife's interest rate
* DATE CREATED: 1/18/2013
* UPDATES: Incorporate wave II follow up data into second 
*	draft of the paper
* UPDATE TO SUBMIT TO JPE
* UPDATE TO SUBMIT TO AEJ APPLIED
* ************************************************************

***********************************************************
* DO FILE FOR COMPIERS DATA SET
***********************************************************
global dohetfile "${dopath}/LongRun_4a_HetMakeData.do"

***********************************************************
* CONTROL SET FOR INDIVIDUAL REGRESSIONS
***********************************************************
#delimit ;

global base "";
global cont2 "sd_ba sd_sacco sd_sacco_miss sd_rosca sd_rosca_miss sd_hh sd_hh_miss female 
			  age edu literate literate_miss kids kids_miss occup_sfarm occup_entre occup_sfarm_miss 
			  W99a11 W99a11_miss save_me save_sp save_me_miss 
	          frac_hyp frac_rev frac_hyp_miss beta3 village_dist W99b2 b2_miss W99b6 b6_miss W99b10 b10_miss";         	         
global cont "$base $cont2";       
#delimit cr	
global Wbase "" // easy way to check for robustness to addl controls


***********************************************************
****************** TABLE FORMATTING ********************
***********************************************************
#delimit ;
global footnote0 "Notes: Robust standard errors clustered at the couple level in parentheses, Benjamini et al. (2006) sharpened q-values in brackets. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile. In 2009 Ksh $80\approx$ USD1. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run 
	from 0.2-1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";

global footnote "Notes: Robust standard errors clustered at the couple level in parentheses, Benjamini et al. (2006) sharpened q-values in brackets. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run 
	from 0.2-1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";	
global footnoteNP "Notes: Robust standard errors clustered at the couple level in parentheses. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run 
	from 0.2-1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";	
	
global footnote_atm "Notes: Robust standard errors clustered at the couple level in parentheses. All regressions include additional controls for whether an individual was selected 
	for an "ex-ante" ATM card, whether the spouse was selected for an "ex-ante" ATM card, whether the joint account was selected for an "ex-ante" ATM card, whether the couple was 
	selected for the "extra statements" information sharing treatment, and a dummy variable indicating the first 6 experimental sessions. 
	Pooled regressions include a dummy for survey round. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run 
	from 0.2-1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";	

global footnoteJ "Notes: Robust standard errors clustered at the couple level in parentheses, Benjamini et al. (2006) sharpened q-values in brackets. The individual interest rate is 
	renormalized to run from 0-1, while the joint interest rate is renormalized to run 
	from 0.2-1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";	

global footnoteJ_atm "Notes: Robust standard errors clustered at the couple level in parentheses. All regressions include additional controls for whether an individual was selected 
	for an "ex-ante" ATM card, whether the spouse was selected for an "ex-ante" ATM card, whether the joint account was selected for an "ex-ante" ATM card, whether the couple was 
	selected for the "extra statements" information sharing treatment, and a dummy variable indicating the first 6 experimental sessions. 
	The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run 
	from 0.2-1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";		
global footnote_max "Notes: Heteroskedasticity robust standard errors in parentheses. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile. In 2009 Ksh $80\approx$ USD1. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";		
	
global footnote_couple "Notes: Heteroskedasticity robust standard errors in parentheses. When only one spousal report for a given variable is non-missing, I set the dependent variable to this value. 
	All regressions include a dummy variable to identify these cases. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. This regression imposes the restriction that individual interest rates and cash prizes given to husbands
	and wives have the same impact on household outcomes. Covariates are scaled so that the effect of a one unit change an independent variable can be interpreted as the effect of giving one spouse the highest interest rate/a cash prize.
	DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";
global footnote_couple2 "Notes: Heteroskedasticity robust standard errors (clustered at the couple level when relevant) in parentheses. When only one spousal report for a given variable is non-missing, I set the dependent variable to this value. 
	All regressions include a dummy variable to identify these cases. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. This regression imposes the restriction that individual interest rates and cash prizes given to husbands
	and wives have the same impact on household outcomes. Covariates are scaled so that the effect of a one unit change an independent variable can be interpreted as the effect of giving one spouse the highest interest rate/a cash prize.
	DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";

global footnote_coupleE "Notes: Heteroskedasticity robust standard errors in parentheses. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. This regression imposes the restriction that individual interest rates and cash prizes given to husbands
	and wives have the same impact on household outcomes. Covariates are scaled so that the effect of a one unit change an independent variable can be interpreted as the effect of giving one spouse the highest interest rate/a cash prize.
	DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";
global footnote_couple2E "Notes: Heteroskedasticity robust standard errors (clustered at the couple level when relevant) in parentheses. All variables denominated in Kenyan Shillings are top-coded at the 99th
	percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1. This regression imposes the restriction that individual interest rates and cash prizes given to husbands
	and wives have the same impact on household outcomes. Covariates are scaled so that the effect of a one unit change an independent variable can be interpreted as the effect of giving one spouse the highest interest rate/a cash prize.
	DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";
#delimit cr
	
#delimit cr
global prehead1 "\begin{tabular}{l*{"
global prehead2 "}{c}} \hline\hline"


* SET PATH
cd "$finaldata"


* ***************************************************************************
* TABLE 1) BALANCE CHECK -- ATTRITION + SAMPLE OF COUPLES WITH ENDLINE DATA
* ***************************************************************************
use $ind_final, clear
	set more off
	keep if round==0
		replace freeatmI=. if openI==0
		replace freeatmJ=. if openJ==0
		replace freeatmIH=. if openIH==0
		replace freeatmIW=. if openIW==0

g nowave2= Einwave2!=1
replace a11= a11*(52/12)
replace W99a11= W99a11*(52/12)

mat t=J(70,10,.)
foreach out in intrtIH intrtIW intrtJ intrtI intrtI_sp freeatmI freeatmJ cashprize_h cashprize_w cashprize {	
	g `out'2=`out'
	}

local row=1	

la var baselineo "No Endline Survey: Wave 1 & " 
la var nowave2 "No Endline Survey: Wave 2 & " 
la var female "Female & " 
la var age "Age & " 
la var edu "Years Education & " 
la var literate "Literate & " 
la var kids "Number Children & " 
la var polygamous "Polygamous & " 
la var occup_sfarm "Subsistence Farmer & " 
la var occup_entre "Entrepreneur & " 
la var W99a11 "Monthly Income & " 
la var sd_ba "Has Bank Account & " 
la var sd_sacco "Has SACCO Account & " 
la var sd_rosca "ROSCA Participant & "
la var sd_hh "Saves at Home & "
la var W99b2 "Bank Savings & " 
la var W99b6 "SACCO Savings & " 
la var W99b10 "Home Savings & " 
la var save_me "I Mostly Save & " 
la var save_sp "My Spouse Mostly Saves & " 
la var frac_hyp "Impatient Now-Patient Later & " 
la var frac_rev "Patient Now-Impatient Later & " 
la var beta3 "Weekly Discount Factor & " 
la var village_dist "Distance to Bank (Miles) & " 
#delimit ;
local cvars "baselineo nowave2 female age edu literate kids polygamous occup_sfarm occup_entre W99a11 sd_ba sd_sacco sd_rosca sd_hh 
			 W99b2 W99b6 W99b10 save_me save_sp frac_hyp frac_rev beta3 village_dist intrtI2 intrtJ2 cashprize2";
#delimit cr
foreach var in `cvars' {
		local rep=""
		`rep'
			cap replace `var'=. if `var'_miss==1
	sum `var'
		mat t[`row',1]= r(mean)
		local lx`row': variable label `var'			
			local ++row
		mat t[`row',1]= r(sd)
		local ++row
	}
	local maxvar= `row'-2
local col=2
/*
foreach out in intrtI intrtJ cashprize {	
est clear
local str ""
local tst ""

	local row=1
	foreach var in `cvars' {
		
		cap reg `var' `out', clu(ipac)
			mat t[`row',10]=e(N)
			mat t[`row',`col']= _b[`out']
				local ++row
			mat t[`row',`col']= _se[`out']
				local ++row
		cap reg `var' `out' 
			est store E`var'_`out'
			if "`var'"!="baselineo" & "`var'"!="nowave2" & substr("`var'",1,3)!="int" & substr("`var'",1,4)!="free" & "`var'"!="myint2" & "`var'"!="cashprize2" & "`var'"!="cashprize_h2" & "`var'"!="cashprize_w2" {
				local str "`str' E`var'_`out'"
				local tst "`tst' [E`var'_`out'_mean]`out'="
				}
		}
		suest `str', vce(cluster ipacou)
			test `tst'0
			mat t[`row',`col']=r(p)
		local ++col
				
		}
		*/
drop _all
svmat t		
		g marker=1 if _n<=54
		g coeff= round(_n/2)!=_n/2 & marker==1
		g coeff2=0
		g se= round(_n/2)==_n/2 & marker==1
		replace coeff=0 if _n==55

tableme t1, coeff(coeff2) mark(marker) se(se) sig(3) maxdec(3) bracket
tableme t2-t9, coeff(coeff) mark(marker) se(se) sig(3) maxdec(3)
order t1-t9 t10
list t1-t10,  clean noobs
	g t0=""
di "`maxvar'"
		forval i=1/`maxvar' {
			replace t0="`lx`i''" if _n==`i'
			}
	tostring t10, replace
		replace t10="" if t10=="."
	drop if _n>=49 & _n<=54
	replace t1="" if t1=="."
	replace t3="--" if _n==5 | _n==6
	replace t0= "P-value -- Joint Test & " if _n==49
	
forval i=1/4 {
	replace t`i'= t`i'+" & " if (t`i'!="." & t`i'!="") | _n==49
	replace t`i'= "" if t`i'=="."
	}
	replace t10= t10+" \\ " if t10!=""
	replace t10= "& \\ " if t10=="" & t2!=""
	g index=_n
		replace index=0 if index==50
		drop if index>51
		sort index
list index t0 t1-t4 t10, clean noobs

#delimit ;
local fn "Notes: Standard deviations in brackets, robust standard errors clustered at the couple level in parentheses. Each 
		row represents a separate regression.
		All income and savings variables top-coded at the 99th percentile. In 2009 Ksh 80 $\approx$ USD1. The joint test 
		is an F-test of the null hypotheses that the coefficients on the treatment variable across all equations/outcomes 
		are jointly equal to zero. The individual interest rate is renormalized to run from 0-1, while the joint interest 
		rate is renormalized to run from 0.2-1. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";
global text0 "\begin{table}[h!] \begin{adjustbox}{max width=.67\textwidth} \begin{threeparttable} \caption{Demographic Characteristics and Randomization Verification} \label{balance} { 
			\begin{tabular}{l*{6}{c}} \hline\hline & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)} \\
			& \multicolumn{1}{c}{Variable} & \multicolumn{2}{c}{Interest Rates} & \multicolumn{1}{c}{Cash} &  \\ 
			\cmidrule(lr){3-4} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{Individual} & \multicolumn{1}{c}{Joint} & \multicolumn{1}{c}{Prize} & \multicolumn{1}{c}{N}  \\ \hline";
global textlast "\hline \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr	
	replace t0="$text0" if _n==1
	replace t0="$textlast" if _n==_N
	replace t0=" & " if t1!="" & _n>=2 & _n<_N & t0==""
outfile t0 t1-t4 t10 using "${out_sheet}/_LatexParts/balance.tex", noquote replace wide		

	
	
* ********************************************************************************************
* IMPACTS ON LONG RUN ECONOMIC OUTCOMES, BUSINESS OUTCOMES
* *********************************************************************************************
use $ind_final, clear

* STEP 1 :: STORE P-VALUES FOR TESTS FOR ALL FDR-CORRECTED SPECIFICATIONS

// list of outcomes that are included in FDR-adjusted tables
#delimit ;
	local fdrlist "openI saved_6mI Wbal_6mI openJ saved_6mJ Wbal_6mJ saved_any6m Tbal_6m 
				   Wdep_amt_6mI Wwith_amt_6mI Wdep_amt_6mJ Wwith_amt_6mJ Tdep_amt_6m Twith_amt_6m
				   active_last12I Wbal_3yI active_last12J Wbal_3yJ active_last12 Tbal_3y Esd_ba_any EW99save_ba
				   EW99total_assets EW99netass EW99inc_lastm E2W99inc_monthly INCOME lass linc1 linc2 linc
				   Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_business E2W99profit_monthly WE2labor_ownb  HAS_PROFIT PROFIT				   
				   LEvalue_livestock anyreno Egood_roof Eladder_spend Eladder_amtsave Esave_both
				   E2save_priority E2reg_saver E2hasacct_bus E2inflex_bus
				   EW99inc_lastm_r EW99total_assets_r EW99inc_bus_r EW99save_bus_r EW99inc_lastm_j EW99total_assets_j EW99inc_bus_j EW99save_bus_j
				   EW99value_livestock EW99save_rosca EW99save_sacco EW99save_mpesa EW99save_home EW99save_otherinv
				   EW99inc_farm EW99inc_wage EW99inc_oth
				   EW99debt_banks EW99debt_mfi EW99debt_family EW99debt_moneylend EW99debt_shops EW99debt_other";
#delimit cr


// extract p-values for core regression specification
local rct= wordcount("`fdrlist'")
	di `rct'
	mat PintrtI= J(`rct',1,.)
		mat rownames PintrtI= `fdrlist'
	mat PintrtI_sp= PintrtI
	mat PintrtJ= PintrtI
	mat Pcashprize= PintrtI
	mat Pcashprize_sp= PintrtI
local row=1	
foreach var in `fdrlist' {
	qui reg `var' intrtI intrtI_sp intrtJ cashprize cashprize_sp i.round $Wbase, clu(ipac)
		est store `var'
		foreach cov in intrtI intrtI_sp intrtJ cashprize cashprize_sp {
			qui test `cov'=0
			mat P`cov'[`row',1]=r(p)
			}
		local ++row
		}


// calculate sharpened q-values

foreach cov in intrtI intrtI_sp intrtJ cashprize cashprize_sp {
drop _all
svmat P`cov'
	ren P`cov' pval
	qui do "$dopath/LongRun_4b_fdr_sharpened_qvalues.do"
	sort original_sorting_order
	mkmat bky, mat(Q`cov')
		mat rownames Q`cov'= `fdrlist'
	}
	
cap prog drop makinit
		prog define makinit, eclass
		args outcome
est restore `outcome'
	mat X= J(1,7,1)
	local col=1
	mat X=e(b)
		mat X[1,6]=1
		mat X[1,7]=1
	foreach cov in intrtI intrtI_sp intrtJ cashprize cashprize_sp {
		mat X[1,`col']= Q`cov'[rownumb(Q`cov',"`outcome'"),1]
			local ++col
		}
	
	eret matrix pv = X
	eret local cmd "makinit"
	est store Q`outcome'
	end
	/*
foreach var in `fdrlist' {
	makinit `var'
	}
*/
	
	

use $ind_final, clear

// Short run account use
coretable_fdr openI saved_6mI Wbal_6mI openJ saved_6mJ Wbal_6mJ saved_any6m Tbal_6m, extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/SRadmin_main.tex) footnote($footnote0) ///
		prehead1($prehead1) title("Use of Experimental Bank Accounts in First 6 Months") lab(SRadmin_main) ///
	    prehead2($prehead2 & \multicolumn{3}{c}{Individual Accounts} & \multicolumn{3}{c}{Joint Accounts} & \multicolumn{2}{c}{All Accounts} \\ \cmidrule(lr){2-4} \cmidrule(lr){5-7} \cmidrule(lr){8-9})  
// appendix -- deposits and withdrawals
coretable_fdr Wdep_amt_6mI Wwith_amt_6mI Wdep_amt_6mJ Wwith_amt_6mJ Tdep_amt_6m Twith_amt_6m, extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/SRadmin_appendix.tex) footnote($footnote0) ///
		prehead1($prehead1) title("Use of Experimental Bank Accounts in First 6 Months - Additional Outcomes") lab(SRadmin_appendix) ///
	    prehead2($prehead2 & \multicolumn{2}{c}{Individual Accounts} & \multicolumn{2}{c}{Joint Accounts} & \multicolumn{2}{c}{All Accounts} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7})  
		
	
// Long run account use
coretable_fdr active_last12I Wbal_3yI active_last12J Wbal_3yJ active_last12 Tbal_3y Esd_ba_any EW99save_ba, extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LRadmin_main.tex) footnote($footnote) ///
		prehead1($prehead1) title("Long-Run Use of Bank Accounts") lab(LRadmin_main) ///
	    prehead2($prehead2 & \multicolumn{6}{c}{Experimental Accounts in Year 3 (Admin. Data)} & \multicolumn{2}{c}{\specialcell{All Banks in Year 3 \\ (Endline Data)}} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-9} & \multicolumn{2}{c}{Individual Accounts} & \multicolumn{2}{c}{Joint Accounts} & \multicolumn{2}{c}{Ind. and Joint} & \multicolumn{2}{c}{All Accounts} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9})  

// GROUP 1 :: MAIN ECONOMIC OUTCOMES
coretable_fdr EW99total_assets EW99netass EW99inc_lastm E2W99inc_month INCOME lass linc1 linc2 linc, extra("$Wbase" round) type(tex) ///
		table(${out_sheet}/_LatexParts/LR_econ_main.tex) footnote($footnote) ///
		prehead1($prehead1) title("Long-Run Impacts on Overall Economic Outcomes") lab(LR_econ_main) ///
	    prehead2($prehead2 & \multicolumn{5}{c}{Level Values} & \multicolumn{4}{c}{Hypersine} \\ \cmidrule(lr){2-6} \cmidrule(lr){7-10})  
		
coretable_ltx EW99total_assets EW99netass EW99inc_lastm E2W99inc_month INCOME lass linc1 linc2 linc, extra("$Wbase" round synth_atmI synth_atmI_sp synth_atmJ es sessdum) type(tex) ///
		table(${out_sheet}/_LatexParts/LR_econ_atm.tex) footnote($footnote_atm) ///
		prehead1($prehead1) title("Long-Run Impacts on Overall Economic Outcomes - Control for ATM Card and Information Sharing Treatments") lab(LR_econ_atm) ///
	    prehead2($prehead2 & \multicolumn{5}{c}{Level Values} & \multicolumn{4}{c}{Hypersine} \\ \cmidrule(lr){2-6} \cmidrule(lr){7-10})  		
lintable_ltx EW99total_assets EW99netass EW99inc_lastm E2W99inc_month INCOME lass linc1 linc2 linc, extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LR_econ_lin.tex) footnote($footnote) ///
		prehead1($prehead1) title("Long-Run Impacts on Overall Economic Outcomes - Nonlinear Effect of Interest Rates") lab(LR_econ_lin) ///
	    prehead2($prehead2 & \multicolumn{5}{c}{Level Values} & \multicolumn{4}{c}{Hypersine} \\ \cmidrule(lr){2-6} \cmidrule(lr){7-10})  				
		
// GROUP 2 :: BUSINESS OUTCOMES
coretable_fdr Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb  HAS_PROFIT PROFIT, /// 
		extra("$Wbase" round) type(tex) ///
		table(${out_sheet}/_LatexParts/LR_bus_main.tex) footnote($footnote) ///
		prehead1($prehead1) title("Long-Run Impacts on Entrepreneurial Activity") lab(LR_bus_main) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{Wave 1} & \multicolumn{3}{c}{Wave 2} & \multicolumn{2}{c}{Pooled} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-8} \cmidrule(lr){9-10})  

coretable_ltx Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb  HAS_PROFIT PROFIT, /// 
		extra("$Wbase" round  synth_atmI synth_atmI_sp synth_atmJ es sessdum) type(tex) ///
		table(${out_sheet}/_LatexParts/LR_bus_atm.tex) footnote($footnote_atm) ///
		prehead1($prehead1) title("Long-Run Impacts on Entrepreneurial Activity - Control for ATM Card and Information Sharing Treatments") lab(LR_bus_atm) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{Wave 1} & \multicolumn{3}{c}{Wave 2} & \multicolumn{2}{c}{Pooled} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-8} \cmidrule(lr){9-10})  		
lintable_ltx Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb  HAS_PROFIT PROFIT, /// 
		extra("$Wbase" round) type(tex) ///
		table(${out_sheet}/_LatexParts/LR_bus_lin.tex) footnote($footnote) ///
		prehead1($prehead1) title("Long-Run Impacts on Entrepreneurial Activity - Nonlinear Effect of Interest Rates") lab(LR_bus_lin) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{Wave 1} & \multicolumn{3}{c}{Wave 2} & \multicolumn{2}{c}{Pooled} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-8} \cmidrule(lr){9-10})  	

		
// GROUP 3: 'JOINT' OUTCOMES
coretable_fdr LEvalue_livestock anyreno Egood_roof Eladder_spend Eladder_amtsave Esave_both, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LR_joint_main.tex) footnote($footnoteJ) ///
		prehead1($prehead1) title("Long-Run Impacts on Public Goods and Spousal Agreement") lab(LR_joint_main) ///
	    prehead2($prehead2)  
coretable_ltx LEvalue_livestock anyreno Egood_roof Eladder_spend Eladder_amtsave Esave_both, /// 
		extra("$Wbase" synth_atmI synth_atmI_sp synth_atmJ es sessdum) type(tex) ///
		table(${out_sheet}/_LatexParts/LR_joint_atm.tex) /// 
		footnote($footnoteJ_atm) ///
		prehead1($prehead1) title("Long-Run Impacts on Public Goods and Spousal Agreement - Control for ATM Card and Information Sharing Treatments") lab(LR_joint_atm) ///
	    prehead2($prehead2)  
lintable_ltx LEvalue_livestock anyreno Egood_roof Eladder_spend Eladder_amtsave Esave_both, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LR_joint_lin.tex) footnote($footnote) ///
		prehead1($prehead1) title("Long-Run Impacts on Public Goods and Spousal Agreement - Nonlinear Effect of Interest Rates") lab(LR_joint_lin) ///
	    prehead2($prehead2)  
		
// GROUP 4 :: BEHAVIORAL OUTCOMES
coretable_fdr E2save_pri E2reg_save E2hasacct_bus E2inflex_bus, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LR_save_beh.tex) footnote($footnoteJ) ///
		prehead1($prehead1) title("Long-Run Impacts on Savings and Investment Behaviors") lab(LRsaveBeh) ///
	    prehead2($prehead2)  	
		
// GROUP 5 :: INDIV VS JOINT		
coretable_fdr EW99inc_lastm_r EW99total_assets_r EW99inc_bus_r EW99save_bus_r EW99inc_lastm_j EW99total_assets_j EW99inc_bus_j EW99save_bus_j, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LR_indVjoint.tex) footnote($footnoteNP) ///
		prehead1($prehead1) title("Long-Run Impacts on Individually- and Jointly-Held Resources") lab(LRindVjoint) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{Individually-Held Resources} & \multicolumn{4}{c}{Jointly-Held Resources}  \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9})  

// APPENDIX TABLE A4) SAVINGS/ASSETS BY SOURCE
coretable_fdr EW99value_livestock EW99save_rosca EW99save_sacco EW99save_mpesa EW99save_home EW99save_otherinv, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LRassets_detail.tex) footnote($footnoteNP) ///
		prehead1($prehead1) title("Impact of Interest Rates on Other Types of Assets (At Endline 1, Excluding Bank, Business Assets)") lab(LRassets_detail) ///
	    prehead2($prehead2)  
	
	
// APPENDIX TABLE A5) INCOME BY SOURCE
coretable_fdr EW99inc_farm EW99inc_wage EW99inc_oth, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LRinc_detail.tex) footnote($footnoteNP) ///
		prehead1($prehead1) title("Impact of Interest Rates on Income, by Source (At Endline 1, Excluding Business Profits)") lab(LRinc_detail) ///
	    prehead2($prehead2)  
		
		
// APPENDIX TABLE A6: DEBT BY SOURCE
coretable_fdr EW99debt_banks EW99debt_mfi EW99debt_family EW99debt_moneylend EW99debt_shops EW99debt_other, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/LRdebt_detail.tex) footnote($footnoteNP) ///
		prehead1($prehead1) title("Impact of Interest Rates on Debt (At Endline 1), by Source") lab(LRdebt_detail) ///
	    prehead2($prehead2 & \multicolumn{6}{c}{Debt From:}  \\ \cmidrule(lr){2-7})  

// HET BY BASELINE ENTREPRENEURSHIP AND GENDER
local fn "Notes: Standard errors clustered at the couple level in parentheses. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run from 0.2-1.  All variables denominated in Kenyan Shillings are top-coded at the 99th percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1.  All regressions also control for own and spousal cash prize selection. Pooled regressions also control for endline wave. Regressions for entrepreneurs and non-entrepreneurs are jointly estimated using seemingly unrelated regression in order to perform tests of equality. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$."
hettable_ltx Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb E2hasacct_bus  E2inflex_bus HAS_PROFIT PROFIT, ///
	group(occup_entre) group1("Entrepreneurs") group0("Non-Entrepreneurs") 	extra("$Wbase" round) type(tex) ///
		table(${out_sheet}/_LatexParts/het_entre.tex) footnote(`fn') ///
		prehead1($prehead1) title("Heterogeneity in Business Impacts by Baseline Entrepreneurship") lab(het_entre) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{Wave 1 Endline} & \multicolumn{5}{c}{Wave 2 Endline} & \multicolumn{2}{c}{Pooled} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-10} \cmidrule(lr){11-12})  

local fn "Notes: Standard errors clustered at the couple level in parentheses. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run from 0.2-1.  All variables denominated in Kenyan Shillings are top-coded at the 99th percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1.  All regressions also control for own and spousal cash prize selection. Pooled regressions also control for endline wave. Regressions for men and women are jointly estimated using seemingly unrelated regression in order to perform tests of equality. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$."		
hettable_ltx Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb E2hasacct_bus  E2inflex_bus HAS_PROFIT PROFIT, ///
	group(male) group1("Men") group0("Women") 	extra("$Wbase" round) type(tex) ///
		table(${out_sheet}/_LatexParts/het_gender.tex) footnote(`fn') ///
		prehead1($prehead1) title("Heterogeneity in Business Impacts by Gender") lab(het_gender) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{Wave 1 Endline} & \multicolumn{5}{c}{Wave 2 Endline} & \multicolumn{2}{c}{Pooled} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-10} \cmidrule(lr){11-12})  
		
// HET BY BASELINE BANK ACCT OWNERSHIP
local fn "Notes: Standard errors clustered at the couple level in parentheses. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run from 0.2-1.  All variables denominated in Kenyan Shillings are top-coded at the 99th percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1.  All regressions also control for own and spousal cash prize selection. Pooled regressions also control for endline wave. Regressions for baseline banked and unbanked are jointly estimated using seemingly unrelated regression in order to perform tests of equality. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$."		
hettable_ltx LEtotal_assets LEinc_lastm Eoccup_entre Ehasbusinc EW99save_bus EW99inc_bus LE2inc_month E2inflex_bus E2W99profit_mon, ///
	group(sd_ba) group1("Banked") group0("Unbanked") 	extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/het_bank.tex) footnote(`fn') ///
		prehead1($prehead1) title("Heterogeneity by Baseline Bank Account Ownership") lab(het_bank) ///
	    prehead2($prehead2 & \multicolumn{6}{c}{Wave 1 Endline} & \multicolumn{3}{c}{Wave 2 Endline} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-10})  

// REPORTING BIAS CHECK :: MJAZA		
local fn " Standard errors clustered at the couple level in parentheses. The variables in the first two columns run from 0 (least helpful/least likely to sign up) to 10 (most helpful/would definitely sign up). The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run from 0.2-1. The sample sizes in this table are small because these questions were only asked to a subset of respondents. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$."
coretable_ltx Emjaza_help Emjaza_likely help10 like10 , extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/rep_bias.tex) footnote(`fn') ///
		prehead1($prehead1) title("Reporting Bias - Impact of Treatments on Pilot Product Ratings") lab(rep_bias) ///
	    prehead2($prehead2)  		

		
* ******************************************************************************				
* ******************************************************************************		
* Couple-Level Analysis
* ******************************************************************************
* ******************************************************************************
use $ind_final, clear
replace gender="W" if female==1
replace gender="H" if female==0
g totactive= active_last12IH + active_last12IW + active_last12J
g totactive_6m= saved_6mIH + saved_6mIW + saved_6mJ

keep Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb PROFIT HAS_PROFIT INCOME_RAW Etotal_assets EW99total_assets EW99netass EW99inc_lastm E2W99inc_month INCOME intrtI intrtJ ipac cashprize round gender totactive totactive_6m Tbal_6m Tbal_3y Esd_ba_any EW99save_ba Tdep_amt_last12 Tdep_amt_6m
	reshape wide Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_bus E2W99profit_month WE2labor_ownb PROFIT HAS_PROFIT INCOME_RAW Etotal_assets EW99total_assets EW99netass EW99inc_lastm E2W99inc_month INCOME intrtI cashprize totactive totactive_6m Tbal_6m Tbal_3y Esd_ba_any EW99save_ba Tdep_amt_last12 Tdep_amt_6m, i(ipac round) j(gender) string
	
	g intrtI= intrtIH + intrtIW
	g cashprize= cashprizeH + cashprizeW
	g totactive= (totactiveH+totactiveW)/2
	g totactive_6m= (totactive_6mH+totactive_6mW)/2
	

	foreach var in Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_business E2W99profit_monthly WE2labor_ownb PROFIT HAS_PROFIT INCOME_RAW Etotal_assets EW99total_assets EW99netass EW99inc_lastm E2W99inc_monthly INCOME Tbal_6m Tbal_3y Esd_ba_any EW99save_ba Tdep_amt_last12 Tdep_amt_6m {
	egen `var'= rowtotal(`var'H `var'W), missing
	g O`var'= `var'!=. & `var'H+`var'W==.
	// replace `var'= `var'H+`var'W //UNCOMMENT TO CHECK ROBUSTNESS TO ONLY KEEPING COUPLES WITH TWO NON-MISSING REPORTS
	}
	
// take hypersine of sum, not sum of hypersines	
	g linc=  asinh(INCOME_RAW)
	g linc1= asinh(INCOME_RAW) if round==1
	g linc2= asinh(INCOME_RAW) if round==2
	g lass= asinh(Etotal_assets)
		ren OINCOME_RAW Olinc
		ren OEtotal_assets Olass
		g Olinc1= Olinc if round==1
		g Olinc2= Olinc if round==2
		g Ototactive=0
		g Ototactive_6m=0
		
g round2= round==2	
la var EW99total_assets "\specialcell{Total \\ Assets}"
la var EW99netass "\specialcell{Assets \\ Net Debt}"
la var EW99inc_lastm "\specialcell{Monthly \\ Income \\ Wave 1}"
la var E2W99inc_monthly "\specialcell{Monthly \\ Income \\ Wave 2}" 
la var INCOME "\specialcell{Monthly \\ Income \\ Pooled}" 
la var lass "\specialcell{Total \\ Assets}"
la var linc "\specialcell{Monthly \\ Income \\ Pooled}"
la var linc1 "\specialcell{Monthly \\ Income \\ Wave 1}"
la var linc2 "\specialcell{Monthly \\ Income \\ Wave 2}"
la var Eoccup_entre "\specialcell{Main \\ Occupation \\ Entrepreneur}"
la var Ehasbusinc "\specialcell{Operating \\ Business}"
la var EW99save_bus "\specialcell{Business \\ Capital}" 
la var EW99inc_bus "\specialcell{Business \\ Profit}"
la var E2has_business "\specialcell{Operating \\ Business}" 
la var E2W99profit_monthly "\specialcell{Business \\ Profit}"
la var WE2labor_ownb "\specialcell{Hours \\ Worked on \\ Business}"
la var HAS_PROFIT "\specialcell{Operating \\ Business}"
la var PROFIT "\specialcell{Business \\ Profit}"

la var Tdep_amt_6m "\specialcell{Total \\ Deposits \\ 6 Months}" 
la var Tbal_6m "\specialcell{Ending \\ Balance \\ 6 Months}" 

la var totactive_6m "\specialcell{Number \\ Accts. Used \\  6 Months}"
la var totactive "\specialcell{Number \\ Accts. Used \\ Year 3}"
la var Tdep_amt_last12 "\specialcell{Total \\ Deposits \\ Year 3}" 
la var Tbal_3y "\specialcell{Ending \\ Balance \\ Year 3}" 
la var EW99save_ba "\specialcell{Total \\ Account \\ Balance}"
la var Esd_ba_any "\specialcell{Number \\ Spouses \\ Banked}"


// main economic outcomes
coupletable_ltx EW99total_assets EW99netass EW99inc_lastm E2W99inc_monthly INCOME lass linc1 linc2 linc,  extra("$Wbase" round2) type(tex) ///
	  table(${out_sheet}/_LatexParts/LRecon_couple.tex) ///
	  title("Long-Run Impacts on Overall Economic Outcomes -- Couple Level Regressions") lab(LRecon_couple)  ///
	  footnote($footnote_couple2) prehead1($prehead1) ///
	  prehead2($prehead2 & \multicolumn{5}{c}{Level Values} & \multicolumn{4}{c}{Hypersine} \\ \cmidrule(lr){2-6} \cmidrule(lr){7-10})  

// business outcomes	
coupletable_ltx Ehasbusinc Eoccup_entre EW99save_bus EW99inc_bus E2has_business E2W99profit_monthly WE2labor_ownb  HAS_PROFIT PROFIT,  extra("$Wbase" round2) type(tex) ///
	  table(${out_sheet}/_LatexParts/LRbus_couple.tex) ///
	  title("Long-Run Impacts on Entrepreneurial Activity -- Couple Level Regressions") lab(LRbus_couple) ///
	  footnote($footnote_couple2) prehead1($prehead1) ///
	  prehead2($prehead2 & \multicolumn{4}{c}{Wave 1} & \multicolumn{3}{c}{Wave 2} & \multicolumn{2}{c}{Pooled} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-8} \cmidrule(lr){9-10})  

// banking outcomes	
coupletable_ltx Tbal_6m Tdep_amt_6m Tbal_3y Tdep_amt_last12 Esd_ba_any EW99save_ba,  extra("$Wbase" round2) type(tex) ///
	  table(${out_sheet}/_LatexParts/SRadmin_couple.tex) ///
	  title("Short- and Long-Run Use of Bank Accounts -- Couple Level Regressions") lab(SRadmin_couple)  ///
	  footnote($footnote_couple) prehead1($prehead1) prehead2($prehead2 & \multicolumn{4}{c}{\specialcell{ All Experimental Accounts \\ (Admin. Data)}} & \multicolumn{2}{c}{\specialcell{All Banks \\ (Endline Data)}} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-7})
	
* ********************************************************
* TABLE A1: ACCOUNT OPENING DECISIONS
* ********************************************************

use "$finaldata/$couplelevel", clear
	set more off

mat t=J(12,2,.)

g onlyj= openJ==1 & openIH==0 & openIW==0
g onlyhw= openJ==0 & openIH==1 & openIW==1
g all3= openJ + openIH + openIW==3
g onlyjh= openJ==1 & openIH==1 & openIW==0
g onlyjw= openJ==1 & openIH==0 & openIW==1
g onlyh= openJ==0 & openIH==1 & openIW==0
g onlyw= openJ==0 & openIH==0 & openIW==1
g noacct=0
g total=1

la var onlyj "Joint Account Only"
la var onlyhw "Two Individual Accounts Only"
la var all3 "All Three Accounts"
la var onlyjh "Joint and Husband's Account"
la var onlyjw "Joint and Wife's Account"
la var onlyh "Husband's Account Only"
la var onlyw "Wife's Account Only"
la var noacct "Declined to Open Any Account"
la var total "Total"

estpost summarize onlyj onlyhw all3 onlyjh onlyjw onlyh onlyw noacct total
	esttab using "${out_sheet}/_LatexParts/acct_open.tex", cells("mean(fmt(3) label(Share Couples)) sum(fmt(0) label(N) )") noobs label nonum tex frag ///
		prehead(\begin{table}[h!] \caption{Account Opening Decisions} \label{acctopen}  { \begin{tabular}{l*{3}{c}} \hline\hline) ///
		postfoot(\hline \end{tabular} } \end{table}) replace

		
		
* *******************************************************
* TABLE A2: MORE ON ATTRITION
* *******************************************************

use $ind_final, clear
	keep if round==0
	
* CHANGES TO DO IND LEVEL ANALYSIS	
	replace intrtIH= intrtI
	replace intrtIW= intrtI_sp
	replace cashprize_h= cashprize
	replace cashprize_w= cashprize_sp
	
#delimit ;
local cvars "female age edu literate kids polygamous occup_sfarm occup_entre W99a11 sd_ba sd_sacco sd_rosca sd_hh 
			 W99b2 W99b6 W99b10 save_me save_sp frac_hyp frac_rev beta3 village_dist";
local ovars "Esd_ba_ind Esd_ba_joint EW99save_ba_r EW99save_ba_j 
			 EW99total_assets EW99netass EW99inc_lastm Eoccup_entre Ehasbusinc EW99save_bus EW99inc_bus 
			 Evalue_livestock Esave_renovate Egood_roof Eladder_spend Eladder_amtsave Esave_both  
			 E2W99inc_month E2save_pri E2reg_saver E2has_bus E2W99profit_m E2hasacct_bus E2inflex_bus E2labor_ownbus ";
				 
#delimit cr

local mlist ""
foreach out in `ovars' {
		g M_`out'= `out'==.
		local mlist "`mlist' M_`out'"
		}

local mvars ""
local XIvars ""
local XImvars ""
local XI_spvars ""
local XI_spmvars ""
local XJvars ""
local XJmvars ""
local testI ""
local testI_sp ""
local testJ ""

foreach var in `cvars' {
	cap g `var'_miss=0
	local mvars "`mvars' `var'_miss"
		foreach str in I I_sp J {
			g X`str'`var'= intrt`str'*`var'
			g X`str'`var'_miss= intrt`str'*`var'_miss
				local X`str'vars "`X`str'vars' X`str'`var'"
				local Xm`str'vars "`Xm`str'vars' X`str'`var'_miss"
		local test`str' "`test`str'' X`str'`var'="
		}
		}
foreach str in I I_sp J {
	local test`str' "`test`str'' 0"
	}
		
la var Einwave1 "\enspace In Wave 1 Endline" 
la var M_Esd_ba_ind "\enspace Has Individual Bank Account" 
la var M_Esd_ba_joint "\enspace Has Joint Bank Account" 
la var M_EW99save_ba_r "\enspace Individual Bank Savings" 
la var M_EW99save_ba_j "\enspace Joint Bank Savings" 
la var M_EW99total_assets "\enspace Total Assets" 
la var M_EW99netass "\enspace Net Assets" 
la var M_EW99inc_lastm "\enspace Monthly Income"
la var M_Eoccup_entre "\enspace Main Occ. Entrepreneur" 
la var M_Ehasbusinc "\enspace Operating Business" 
la var M_EW99save_bus "\enspace Business Capital" 
la var M_EW99inc_bus "\enspace Business Profits" 
la var M_Evalue_livestock "\enspace Value Livestock" 
la var M_Esave_renovate "\enspace Home Reno. Last Year" 
la var M_Egood_roof "\enspace Has Permanent Roof" 
la var M_Eladder_spend "\enspace Agree: Spend Money" 
la var M_Eladder_amtsave "\enspace Agree: How Much to Save" 
la var M_Esave_both "\enspace Savings: Decide Together" 
la var Einwave2 "\enspace In Wave 2 Endline" 
la var M_E2W99inc_month "\enspace Monthly Income" 
la var M_E2save_pri "\enspace Savings a Priority" 
la var M_E2reg_saver "\enspace Saves Regularly"
la var M_E2has_bus "\enspace Operating Business"
la var M_E2W99profit_m "\enspace Business Profits"
la var M_E2hasacct_bus "\enspace Has Business Budget"
la var M_E2inflex_bus "\enspace Downwardly Rigid Business Budget"
la var M_E2labor_ownbus "\enspace Labor on Own Business"

local namestr=""
mat t2= J(32,6,.)
local row=1 
foreach out in Einwave1 Einwave2 `mlist' {
	reg `out' intrtI , clu(ipac)
		test intrtI=0
		mat t2[`row',1]= r(p)
	reg `out' intrtI_sp , clu(ipac)
		test intrtI_sp=0
		mat t2[`row',2]= r(p)
	reg `out' intrtJ, clu(ipac)
		test intrtJ=0
		mat t2[`row',3]= r(p)

	reg `out' intrtI `cvars' `mvars' `XIvars' `XmIvars', clu(ipac)
		test `testI'
		mat t2[`row',4]= r(p)
	reg `out' intrtI_sp `cvars' `mvars' `XI_spvars' `XmI_spvars', clu(ipac)
		test `testI_sp'
		mat t2[`row',5]= r(p)
	reg `out' intrtJ `cvars' `mvars' `XJvars' `XmJvars', clu(ipac)
		test `testJ'
		mat t2[`row',6]= r(p)
		
	local label`row': variable label `out'
		
local ++row
	}
qui sum Einwave1 
	mat t2[`row',1]= r(N)
	mat t2[`row',4]= r(N) 
qui sum Einwave1 
	mat t2[`row',2]= r(N)
	mat t2[`row',5]= r(N) 
qui sum Einwave1 
	mat t2[`row',3]= r(N)
	mat t2[`row',6]= r(N) 
local row= `row'-1	
drop _all
	svmat t2
	
g t0=""
forval j=1/`row' {
	replace t0= "`label`j''" if _n==`j'
	}
	
forval i=1/6 {
	g t`i'=t2`i'
	}
g marker=_n<=27
g coeff=0
g se=0
		
tableme t1-t6, coeff(coeff) marker(marker) se(se) maxdec(3) sig(3)
	forval i=1/6 {
		replace t`i'= t`i'+"\sym{*}" if t2`i'<=.1 & t2`i'>.05
		replace t`i'= t`i'+"\sym{**}" if t2`i'<=.05 & t2`i'>.01
		replace t`i'= t`i'+"\sym{***}" if t2`i'<=.01
	}
	replace t0="N" if t1=="1558"
forval i=0/5 {
	replace t`i'= t`i'+" & " if t0!=""
	replace t`i'="" if t`i'=="."
	}
	replace t6= t6+ " \\ " if t0!=""
	replace t6="" if t6=="."
	
list t0 t1-t6, clean 
	g index=_n
	replace index=0 if _n==_N-1
	replace index=-1 if _n==_N
	replace index=19.5 if t0=="In Wave 2 Endline & "
	sort index
	replace index= 19.25 if _n==_N
	sort index
		replace t0= "\emph{A. Wave 1 Endline Outcomes} & & & & & & \\" if index==0
		replace t0= "\emph{B. Wave 2 Endline Outcomes} & & & & & & \\" if index==19.25	
#delimit ;
local fn "Notes: P-values are from F-tests of coefficient restrictions on regressions with robust standard errors clustered at the couple level. 
			The underlying regression in the first three columns regresses an indicator for whether the specified outcome is missing on the treatment of interest. 
			The table reports p-values for whether attrition is significantly correlated with treatment. 
			The underlying regression in the last three columns regresses the missing indicator on the treatment of interest, 
			all demographic controls listed in Table 1, and interactions between the demographic variables and the treatment of interest. 
			The table reports the p-value from a joint test of whether the interaction terms are equal to zero. The individual interest rate is renormalized to run from 0-1, 
			while the joint interest rate is renormalized to run from 0.2-1. ***, **, and * indicate significance at the 1 5, and 10 percent levels respectively.";
global text0 "\begin{table}[h!] \begin{adjustbox}{max width=\textwidth} \begin{threeparttable} \caption{Endline Attrition: Correlation with Treatment and Differential Selection} \label{attrn_appdx} { 
			\begin{tabular}{l*{7}{c}} \hline\hline & \multicolumn{3}{c}{\specialcell{P-value: Treatment Correlated With \\ Missing}} & \multicolumn{3}{c}{\specialcell{P-value: Differential Selection on \\ Observables}} \\ \cmidrule(lr){2-4} \cmidrule(lr){5-7}
            &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)} \\
            &\multicolumn{1}{c}{\specialcell{Individual \\ Interest}}&\multicolumn{1}{c}{\specialcell{Spousal \\ Interest}}&\multicolumn{1}{c}{\specialcell{Joint \\ Interest}}&\multicolumn{1}{c}{\specialcell{Individual \\ Interest}}&\multicolumn{1}{c}{\specialcell{Joint \\ Interest}}&\multicolumn{1}{c}{\specialcell{Spousal\\Interest}} \\ \hline";
global textlast "\hline \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";

#delimit cr
	replace t0="$text0" if _n==1
	replace t0="$textlast" if _n==_N
outfile t0 t1-t6 using "${out_sheet}/_LatexParts/attrn_appdx.tex", noquote replace wide		
 	


* ********************************************************************************************
* APPENDIX TABLE A3: IMPACT OF MAX INTEREST RATE
* *********************************************************************************************
set more off
use "$finaldata/$couplelevel", clear

g max10= maxint==10
g max6= maxint==6
g maxJ= intrtJ==maxint
g maxIH= intrtIH==maxint
g maxIW= intrtIW==maxint
g contmean= maxint!=2 

	foreach var in dep_amt_6m with_amt_6m bal_6m avg_bal_6m dep_amt_last12 with_amt_last12 bal_3y {
		fixout `var'IH
		fixout `var'IW
		fixout `var'J
		
		g W`var'= W`var'IH + W`var'IW + W`var'J
		}

foreach var in Wavg_bal_6m Wdep_amt_6m Wbal_6m {
	replace `var'=`var'-300		
	}
	
la var saved_6m "\specialcell{Used}"
la var Wdep_amt_6m "\specialcell{Total \\ Deposits}" 
la var Wwith_amt_6m "\specialcell{Total \\ Withdrawals}"
la var Wbal_6m "\specialcell{Ending \\ Balance}"
la var Wavg_bal_6m "\specialcell{Average \\ Balance}" 
la var active_last12 "\specialcell{Used}" 
la var Wdep_amt_last12 "\specialcell{Total \\ Deposits}"
la var Wwith_amt_last12 "\specialcell{Total \\ Withdrawals}" 
la var Wbal_3y "\specialcell{Ending \\ Balance}" 

g inflation_factor= (131.78 - 102.90) / 102.90 /* Sept quarter CPIs for 2009 and 2012 from http://www.knbs.or.ke/index.php?option=com_phocadownload&view=category&id=8&Itemid=509 */
g inflation_factor2= (140.99 - 102.90) / 102.90 /* Sept quarter CPIs for 2009 and 2013 from http://www.knbs.or.ke/index.php?option=com_phocadownload&view=category&id=8&Itemid=509 */
foreach var in Wdep_amt_last12 Wwith_amt_last12 Wbal_3y {
	replace `var'= `var'/inflation_factor
	}
	
maxtable_ltx saved_6m Wdep_amt_6m Wwith_amt_6m Wbal_6m  active_last12 Wdep_amt_last12 Wwith_amt_last12 Wbal_3y, /// 
		extra("$Wbase") type(tex) ///
		table(${out_sheet}/_LatexParts/maxint.tex) footnote($footnote_max) ///
		prehead1($prehead1) title("Impact of the Maximum Interest Rate on Experimental Bank Account Use") lab(maxint) ///
	    prehead2($prehead2 & \multicolumn{4}{c}{First 6 Months} & \multicolumn{4}{c}{Year 3}  \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9})  

		
				
* *************************************************************************
* APPENDIX TABLE A8: COMPARE RETURN TO CAPITAL ACROSS STUDIES
* *************************************************************************
* DELTA METHOD FOR RETURN TO CAPITAL

set more off
import excel using "${out_sheet}/_LatexParts/r2c_summary.xlsx", firstr clear
	tempfile parta
	save "`parta'"

use $ind_final, clear
keep if Eorig==1 & round==0
	
reg EW99inc_lastm intrtI intrtI_sp intrtJ cashprize cashprize_sp
	est store inc_main
reg EW99total_assets intrtI intrtI_sp intrtJ cashprize cashprize_sp
	local k_main= _b[intrtI]
	est store ass_main

reg EW99inc_bus intrtI intrtI_sp intrtJ cashprize cashprize_sp
	est store inc_bus
reg EW99save_bus intrtI intrtI_sp intrtJ cashprize cashprize_sp
	local k_bus= _b[intrtI]
	est store ass_bus

	mat t=J(7,1,.)
suest inc_main ass_main, vce(clu ipac)
	nlcom [inc_main_mean]intrtI / [ass_main_mean]intrtI
		mat t[1,1]= r(b)
		mat t[2,1]= r(V)
		mat t[2,1]= t[2,1]^.5
		local ret_main= t[1,1]
suest inc_bus ass_bus, vce(clu ipac)
	nlcom [inc_bus_mean]intrtI / [ass_bus_mean]intrtI
		mat t[3,1]= r(b)
		mat t[4,1]= r(V)
		mat t[4,1]= t[4,1]^.5
		local ret_bus= t[3,1]
drop _all

local inv_half_main= `k_main'/(1+.5*`ret_main')^32
local inv_full_main= `k_main'/(1+`ret_main')^32
local inv_half_bus= `k_bus'/(1+.5*`ret_bus')^32
local inv_full_bus= `k_bus'/(1+`ret_bus')^32
	
		svmat t
g marker=1
g coeff= round(_n/2)!=_n/2 & marker==1
g se= round(_n/2)==_n/2 & marker==1
	g t0=""
	g t2=""
	g t3=""
		replace t2= string(round(`inv_half_bus',1)) if _n==3
		replace t3= string(round(`inv_full_bus',1)) if _n==3
			replace t2= string(round(`inv_half_main',1)) if _n==1
			replace t3= string(round(`inv_full_main',1)) if _n==1
replace t0="\enspace Business Assets and Income" if _n==3
replace t0="\enspace \textcolor{white}{McKenzie and Woodruff (2008)}" if _n==2
replace t0="\enspace Total Assets and Income" if _n==1
tableme t1, coeff(coeff) mark(marker) se(se) sig(3) maxdec(3)
	replace t1="" if t1=="."
	drop marker coeff se
append using "`parta'"

g index= _n
	replace index=0 if index==5
	replace index=17 if index==7
	sort index
		foreach var in t0 t1 t2 { 
			replace `var'=`var'+ " & " if index!=0 & index!=6 & index!=17
			}
			replace t3= t3+ " \\ " if index!=0 & index!=6 & index!=17
			
#delimit ;
local fn "Notes: \textsuperscript{a}Estimate (i) is for return to pineapple cultivation, (ii) is return to automotive capital in Accra. \textsuperscript{b}These estimates divide the impact of an 
		in-kind cash grant on monthly profits (Table 3) by the value of the grant (150 cedis).";
global text0 "\begin{table}[h!] \begin{adjustbox}{max width=\textwidth} \begin{threeparttable} \caption{Returns to Capital and External Validity} \label{ret_cap} 
			  {\begin{tabular}{l*{4}{C{0.15\linewidth}}} \toprule \toprule  
			  \multicolumn{4}{l}{\emph{A. Returns to Capital and Time to Effect Size from Temporary Individual Interest Rates}}  \\
			  & \multicolumn{1}{c}{\specialcell{ \textcolor{white}{blank} \\ \textcolor{white}{blank} \\ $\Delta$ Monthly \\ Income/}} & \multicolumn{2}{c}{\specialcell{Initial Investment Needed to \\ Meet Effect Sizes in 32 Months \\ When Marginal Propensity to \\ Reinvest is:}} \\ 
			  \cmidrule(lr){3-4} & \multicolumn{1}{c}{$\Delta$ Capital} & \multicolumn{1}{c}{0.5} & \multicolumn{1}{c}{1} \\
			  \toprule";

global text_mid "\end{tabular} }
				{ \begin{tabular}{l*{4}{C{0.15\linewidth}}}  \\ \multicolumn{4}{l}{\emph{B. Existing Evidence on Returns to Capital in Microenterprises}}  \\
				  \multicolumn{1}{l}{\enspace Paper} & \multicolumn{1}{c}{\specialcell{$\Delta$ Monthly \\ Profit/ \\ $\Delta$ Capital}} & \multicolumn{1}{c}{\specialcell{Monthly Return \\ to Capital}}  & \multicolumn{1}{c}{\specialcell{Maximum \\ Follow-Up \\ Period}} \\ \hline";
			  
global textlast "\hline \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";

#delimit cr
	replace t0="$text0" if _n==1
	replace t0="$textlast" if _n==_N
	replace t0="$text_mid" if index==6
outfile t0 t1 t2 t3 using "${out_sheet}/_LatexParts/ret_cap.tex", noquote replace wide		
 				
	


* *********************************************************************
* APPENDIX TABLE R2: ROBUSTNESS TO TRIM/TOP-CODING
* *************************************************************************
use $ind_final, clear
	keep if Eorig==1 & round==0
	set more off		
	
g Eprofit_monthly2= E2profit_monthly
g Einc_monthly2= E2inc_monthly
	foreach num in 98 95 90 {
		ren E2W`num'profit_monthly EW`num'profit_monthly2
		ren E2W`num'inc_monthly EW`num'inc_monthly2
		}
foreach stem in inc_lastm total_assets inc_bus save_bus  profit_monthly2 inc_monthly2 {
foreach num in "" 99 98 95 90 {
	if "`num'"=="" local count= 99.5
		else local count=`num'
		
	g tE`num'`stem'= E`stem'
		_pctile tE`num'`stem', p(`count')
		replace tE`num'`stem'=. if tE`num'`stem'>r(r1)		
	fixout tE`num'`stem'
	}
	}
	
la var Etotal_assets "\emph{Panel A - Total Assets (Endline 1)}"
la var Einc_lastm "\emph{Panel B - Monthly Income (Endline 1)}"
la var Esave_bus "\emph{Panel C - Business Capital (Endline 1)}"
la var Einc_bus "\emph{Panel D - Business Profit (Endline 1)}"
la var Einc_monthly2 "\emph{Panel E - Monthly Income (Endline 2)}"
la var Eprofit_monthly2 "\emph{Panel F - Business Profit (Endline 2)}"
	
foreach bit in total_assets inc_lastm save_bus inc_bus profit_monthly2 inc_monthly2  {
	g `bit'= E`bit'
	}
	
r1pantable_ltx total_assets inc_lastm save_bus inc_bus profit_monthly2 inc_monthly2  , extra("$Wbase") type(tex) /// 
	  table(${out_sheet}/_LatexParts/robust_trTC.tex) ///
	  title("Robustness of Main Results to Additional Topcoding and Trimming") lab(robust_trTC) widc(0.12\linewidth) ///
	  footnote($footnoteNP) 	
	
	
* *************************************************************************
* APPENDIX TABLE R3 IMPUTATIONS
* *************************************************************************
cd "$finaldata"
set more off
use $ind_final, clear
	keep if round==0
	
* CHANGES TO DO IND LEVEL ANALYSIS	
	replace intrtIH= intrtI
	replace intrtIW= intrtI_sp
	replace cashprize_h= cashprize
	replace cashprize_w= cashprize_sp
	
g EW99total_assets2= EW99total_assets
g Etotal_assets2= Etotal_assets
g all=1
foreach var in save_rosca_r save_rosca_j save_ba_r save_ba_s save_ba_j save_bus_r save_bus_j save_bus_s save_otherinv_r save_otherinv_s save_otherinv_j ///
	save_home_r save_home_s save_home_j save_sacco_r save_sacco_s save_sacco_j save_mpesa_r save_mpesa_s save_mpesa_j /// 
	save_renovate_r save_renovate_s save_renovate_j inc_bus_r inc_bus_s inc_bus_j inc_farm_r inc_farm_s inc_farm_j inc_oth_r inc_oth_s inc_oth_j /// 
	inc_wage_r inc_wage_s inc_wage_j value_livestock ///
	debt_family_r debt_family_s debt_family_j debt_banks_r debt_banks_s debt_banks_j debt_mfi_r debt_mfi_s debt_mfi_j debt_moneylend_r debt_moneylend_s /// 
	debt_moneylend_j debt_shops_r debt_shops_s debt_shops_j debt_other_r debt_other_s debt_other_j occup_entre hasbusinc 2inc_monthly 2profit_monthly {


g E`var'_MEAN= E`var'
g E`var'_PRED= E`var'
g E`var'_REV= E`var'
g E`var'_PER= E`var'
	
foreach gender in all {
qui sum E`var' if `gender'
	replace E`var'_MEAN= r(mean) if E`var'==. & `gender'

reg E`var' $cont if `gender'
	predict XB_`var' if `gender', xb
	replace E`var'_PRED= XB_`var' if E`var'==. & `gender'
	drop XB_`var'

g E`var'_M=E`var'
_pctile E`var'_M if `gender', p(20)
	replace E`var'_PER= r(r1) if E`var'==. & intrtIH==1 & `gender'
_pctile E`var'_M if `gender', p(40)
	replace E`var'_PER= r(r1) if E`var'==. & round(intrtIH*10)==6 & `gender'
_pctile E`var'_M if `gender', p(60)
	replace E`var'_PER= r(r1) if E`var'==. & round(intrtIH*10)==2 & `gender'
_pctile E`var'_M if `gender', p(80)
	replace E`var'_PER= r(r1) if E`var'==. & intrtIH==0	& `gender'	
drop E`var'_M


g E`var'_M=E`var'
sum E`var'_M if intrtI==0 & `gender'
	replace E`var'_REV= r(mean) if E`var'==. & round(intrtIH*10)==10 & `gender'
sum E`var'_M if round(intrtIH*10)==2 & `gender'
	replace E`var'_REV= r(mean) if E`var'==. & round(intrtIH*10)==6 & `gender'
sum E`var'_M if round(intrtIH*10)==6 & `gender'
	replace E`var'_REV= r(mean) if E`var'==. & round(intrtIH*10)==2 & `gender'
sum E`var'_M if intrtI==1 & `gender'
	replace E`var'_REV= r(mean) if E`var'==. & intrtIH==0 & `gender'		
drop E`var'_M

}
}

foreach stem in save_rosca save_ba save_bus save_otherinv save_home save_sacco save_mpesa save_renovate inc_bus inc_farm inc_oth inc_wage ///
	debt_family debt_banks debt_mfi debt_moneylend debt_shops debt_other value_livestock 2inc_monthly 2profit_monthly {
	
foreach ends in MEAN PRED REV PER {					
	   cap g E`stem'_`ends'= E`stem'_r_`ends' + E`stem'_j_`ends'
	   cap g EW99`stem'_`ends'= E`stem'_`ends'
		replace EW99`stem'_`ends'= E`stem'_`ends'
			_pctile E`stem'_`ends', p(99)
				replace EW99`stem'_`ends'= r(r1) if E`stem'_`ends'>r(r1) & E`stem'_`ends'!=.
	}		
	}

foreach ends in MEAN PRED REV PER {
foreach beg in "" W99 {
		 g E`beg'inc_lastm_`ends'= E`beg'inc_bus_`ends' + E`beg'inc_wage_`ends' + E`beg'inc_farm_`ends' + E`beg'inc_oth_`ends' 
		 g E`beg'total_assets_`ends'= E`beg'save_rosca_`ends' + E`beg'save_ba_`ends' + E`beg'save_bus_`ends' + E`beg'save_otherinv_`ends' + /// 
		 	E`beg'save_home_`ends' + E`beg'save_sacco_`ends' + E`beg'save_mpesa_`ends' + .5*E`beg'value_livestock_`ends'
				replace E`beg'total_assets_`ends'= E`beg'total_assets_`ends'+.5*E`beg'value_livestock_`ends' if Emarr==0
		 g E`beg'debt_`ends'= E`beg'debt_family_`ends' + E`beg'debt_banks_`ends' + E`beg'debt_mfi_`ends' + E`beg'debt_moneylend_`ends' + E`beg'debt_shops_`ends' + E`beg'debt_other_`ends'
	
	g E`beg'netass_`ends'= E`beg'total_assets_`ends' - E`beg'debt_`ends'
	}
	fixout Etotal_assets_`ends'
	fixout Einc_lastm_`ends'
	} 

foreach var in EW99total_assets_MEAN EW99total_assets_PRED EW99total_assets_REV EW99total_assets_PER ///
	 		   EW99inc_lastm_MEAN EW99inc_lastm_PRED EW99inc_lastm_REV EW99inc_lastm_PER ///
	 		   EW99save_bus_MEAN EW99save_bus_PRED EW99save_bus_REV EW99save_bus_PER ///
	 	       EW99inc_bus_MEAN EW99inc_bus_PRED EW99inc_bus_REV EW99inc_bus_PER { 
	 	       		g `var'H= `var' if male
	 	       		g `var'W= `var' if female
	 	       		}

g EW992inc_monthly= EW992inc_monthly_MEAN
g EW992profit_monthly= EW992profit_monthly_MEAN
foreach var in EW99total_assets EW99inc_lastm EW99save_bus EW99inc_bus EW992inc_monthly EW992profit_monthly {
	la var `var'_MEAN "\emph{Panel A - Impute Mean Values}"
	la var `var'_PRED "\emph{Panel B - Predict Missing Values Using Baseline Covariates}"
	la var `var'_REV "\emph{Panel C - Reverse Imputation by Individual Interest Rate}"
	la var `var'_PER "\emph{Panel D - Percentile Imputation by Individual Interest Rate}"
	}
la var EW99total_assets "\specialcell{Total Assets \\ (EL1)}"
la var EW99inc_lastm "\specialcell{Monthly \\ Income \\ (EL11)}"
la var EW99save_bus "\specialcell{Business \\ Capital \\ (EL1)}"
la var EW99inc_bus "\specialcell{Business \\ Profit \\ (EL1)}"
la var EW992inc_monthly "\specialcell{Monthly \\ Income \\ (EL2)}"
la var EW992profit_monthly "\specialcell{Business \\ Profit \\ (EL2)}"
	
#delimit ;
global fn_impute "Notes: Standard errors clustered at the couple level in parentheses. All regressions control for individual and spousal cash 
	prize selection. The individual interest rate is renormalized to run from 0-1, while the joint interest rate is renormalized to run from 0.2-1. 
	All variables are top-coded at the 99th percentile and deflated to 2009 values. In 2009 Ksh $80\approx$ USD1.  In Panel A, missing values of the dependent 
	variable are replaced with overall means among 
	non-missing observations. In Panel B, missing values are replaced by predicted values obtained by regressing the dependent variable of interest on the 
	baseline control set listed in Table 1. In Panel C, missing values in the 0 percent individual interest rate group are replaced by the mean value in the 
	20 percent individual interest rate group. Missing values in the 4 percent interest group are replaced with the mean in the 12 percent interest group, 
	missing values in the 12 percent interest group are replaced with the mean in the 4 percent interest group, and missing values in the 20 percent interest 
	group are replaced with the mean value in the 0 percent interest group. In Panel D missing values in the 0 percent individual interest group are replaced 
	with the 80th percentile among non-missing values. Missing values in the 4 percent interest group are replaced with the 60th percentile, missing values in the 
	12 percent interest group are replaced with the 40th percentile, and missing values in the 20 percent interest group are replaced with the 20th 
	percentile. DV Mean refers to the dependent variable mean. * p$\le0.10$, ** p$\le0.05$, *** p$\le0.10$.";
#delimit cr

r2pantable_ltx EW99total_assets EW99inc_lastm EW99save_bus EW99inc_bus EW992inc_monthly EW992profit_monthly, extra("$Wbase") type(tex) /// 
	  table(${out_sheet}/_LatexParts/robust_imp.tex) ///
	  title("Robustness of Main Results to Imputing Missing Values") lab(robust_imp) widc(0.12\linewidth) ///
	  footnote($fn_impute) 	
 	 

* *************************************************************
* APPENDIX TABLE AX1: WHY EL2 INCOMES ARE SUSPECT
* *************************************************************
cd "$finaldata"
set more off
use $ind_final, clear
	keep if round==0
	
	replace a11= a11*(52/12)
	replace W99a11= W99a11*(52/12)
	replace W99a11=. if a11_miss==1
	
mat t=J(6,3,.)
local col=1
foreach b in M W D {
	corr edu W99a11 EW99inc_lastm E2W99inc_m if E2inc_int=="`b'"
		mat test=r(C)
		forval i=3/5 {
		mat t[`i'-1,`col']= test[`i'-1,1]
		}
		count if E2inc_int=="`b'"
		mat t[5,`col']= r(N)
	local ++col
	}
drop _all
svmat t
list t1-t3, clean noobs
	forval i=1/3 {
		format t`i' %9.3f
		tostring t`i', replace usedis force
		replace t`i'= substr(t`i',1,3) if _n==_N-1
		replace t`i'="" if t`i'=="."
		}
list t1-t3, clean noobs
	replace t1= t1+" & " if t1!=""
	replace t2= t2+" & " if t2!=""
	replace t3= t3+" \\ " if t3!=""
	g t0=""
		replace t0="Baseline & " if _n==2
		replace t0="Endline 1 & " if _n==3
		replace t0="Endline 2 & " if _n==4
		replace t0="N & " if _n==5
		
#delimit ;
local fn "Notes: This table reports the correlation coefficient between monthly income at either baseline, endline 1, or endline 2 
			and education (as recorded at baseline). The first column reports correlations for individuals who chose to report income 
			on a monthly basis at endline 1. The second column reports correlations for individuals who reported income on a weekly basis 
			at endline 2, and the third column reports correlations for those who reported income on a daily basis at endline 2. 
			All income measures are top-coded at the 99th percentile.";
global text0 "\begin{table}[h!] \begin{adjustbox}{max width=\textwidth} \begin{threeparttable} \caption{Correlation Between Income and Education by Round and Endline 2 Reporting Interval} \label{corr_report} { 
			\begin{tabular}{l*{4}{c}} 
			\hline\hline  &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)} \\
            &\multicolumn{1}{c}{\specialcell{Monthly}}&\multicolumn{1}{c}{\specialcell{Weekly}}&\multicolumn{1}{c}{\specialcell{Daily}} \\ \hline";
global textlast "\hline \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr
	replace t0="$text0" if _n==1
	replace t0="$textlast" if _n==_N
outfile t0 t1-t3 using "${out_sheet}/_LatexParts/corr_report.tex", noquote replace wide		
 	
	


* *************************************************************************
* TABLE AX2: EXTERNAL VALIDITY
* *************************************************************************
set more off

***********************************************************************************
* Note: Running LongRun_4c_ExternalValidity.do file requires access to the Kenya   
*       Census and financial access data. These datasets are publicly available
*		and can be downloaded from IPUMS international (Kenya Census) and FSD Kenya
************************************************************************************

/*
do "$dopath/LongRun_4c_ExternalValidity.do"
*/
	drop _all
svmat t
g index=_n
list index t1-t3, clean noobs
	replace index=0 if _n==14
	drop if index>15
	
	forval i=1/3 {
		g x`i'=t`i'
		format t`i' %9.3f
		tostring t`i', replace usedis force
		tostring x`i', replace usedis force		
		replace t`i'= x`i' if index==13
		replace t`i'="" if t`i'=="."
		replace t`i'="--" if t`i'=="-99.000"
		drop x`i'
		}
		sort index
		drop if index==12 | index==5
list index t1-t3, clean noobs
forval i=1/3 {
	replace t`i'= t`i'+" & " if t`i'!=""
	}
	*replace t6= t6+" \\ " if t6!=""
	g t0=""
		replace t0="Age & " if _n==2
		replace t0="Education & " if _n==3
		replace t0="Children Born (Women Only) & " if _n==4
		replace t0="Polygamous & " if _n==5
		replace t0="Self Employed -- Census Definition & " if _n==6
		replace t0="Self Employed -- Study Definition & " if _n==7
		replace t0="Has Bank Account & " if _n==8
		replace t0="Uses ROSCA & " if _n==9
		replace t0="Has SACCO Account & " if _n==10
		replace t0="Has Mobile Money Account\sym{*} & " if _n==11
		replace t0="N & " if _n==12
list index t0 t1-t3, clean noobs

#delimit ;
local fn "Notes: \sym{*}Information on mobile money usage was not collected for individuals in the first 6 experimental sessions of the study. 
		The first three columns report weighted estimates from the 2009 Kenyan Census, obtained from IPUMS International. The next two columns present 
		weighted estimates from Financial Sector Deepening's 2009 FinAccess household survey, which is representative down to the province level. 
		The study version of entrepreneur includes commercial farmers and businesses involving trade in livestock. The census version of entrepreneur 
		excludes agriculture and livestock occupations. All statistics are reported for married individuals aged 18 and above.";
global text0 "\begin{table}[h!] \begin{adjustbox}{max width=\textwidth} \begin{threeparttable} \caption{Comparing the Study Sample to the Broader Population of Kenyans} \label{ext_val} { 
			\begin{tabular}{l*{7}{c}} \hline\hline & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)} & \multicolumn{1}{c}{(6)} \\
			& \multicolumn{3}{c}{\specialcell{2009 Kenya Census}} & \multicolumn{2}{c}{\specialcell{FinAccess 2009}} & \multicolumn{1}{c}{Study} \\ 
			\cmidrule(lr){2-4} \cmidrule(lr){5-6} & \multicolumn{1}{c}{All Kenya} & \multicolumn{1}{c}{Western Kenya} & \multicolumn{1}{c}{Study Districts} & \multicolumn{1}{c}{All Kenya} & \multicolumn{1}{c}{Western Kenya} & \multicolumn{1}{c}{Sample} \\ \hline";
global textlast "\hline \end{tabular} } \begin{tablenotes}[flushleft] \small 
		\item `fn' 
		\end{tablenotes} \end{threeparttable} \end{adjustbox} \end{table}";
#delimit cr	
	replace t0="$text0" if _n==1
	replace t0="$textlast" if _n==_N

outfile t0 t1-t3 using "${out_sheet}/_LatexParts/ext_val.tex", noquote replace wide		
	
	
* *******************************************************************
* FIGURE: ACCOUNT USE OVER TIME
* *******************************************************************

use "$acctpath_raw/$accts_quarterly", clear
	g lbal= ln(bal+100)
	g joint= acct=="J"
	replace acct="I" if acct=="IH" | acct=="IW"
	g cashprize_h= cashprizeamt_h!=.
	g cashprize_w= cashprizeamt_w!=.
	drop if qdate==1 & (cashprize_h==1 & acct=="IH") | (cashprize_w==1 & acct=="IW") | ((cashprize_h==1 | cashprize_w==1) & acct=="J")
	egen tc= pctile(bal) if acct=="I", p(97.4) by(qdate)
	egen tcJ= pctile(bal) if acct=="J", p(98.5) by(qdate)
	replace tc= tcJ if acct=="J"
		replace bal= tc if bal>tc & bal!=.
collapse (sum) USED dep dep_amt withd with_amt bal, by(intrt joint qdate acct)

* calculate average per interest rate
foreach var in USED /*dep dep_amt withd with_amt*/ bal {

* NOTE: HERE I AM ONLY USING NON-CASH PRIZE OBS FOR THE FIRST QUARTER TO REDUCE SPIKE
	replace `var'= `var'/(177+162) if intrt==0 & joint==0 & qdate==1
	replace `var'= `var'/(157+156) if intrt==2 & joint==0 & qdate==1
	replace `var'= `var'/(167+169) if intrt==6 & joint==0 & qdate==1
	replace `var'= `var'/(138+139) if intrt==10 & joint==0 & qdate==1			

	replace `var'= `var'/181 if intrt==2 & joint==1 & qdate==1
	replace `var'= `var'/172 if intrt==6 & joint==1 & qdate==1
	replace `var'= `var'/165 if intrt==10 & joint==1 & qdate==1
	

	replace `var'= `var'/(189+213) if intrt==0 & joint==0 & qdate!=1
	replace `var'= `var'/(193+202) if intrt==2 & joint==0 & qdate!=1
	replace `var'= `var'/(201+203) if intrt==6 & joint==0 & qdate!=1
	replace `var'= `var'/(172+185) if intrt==10 & joint==0 & qdate!=1			

	replace `var'= `var'/249 if intrt==2 & joint==1 & qdate!=1
	replace `var'= `var'/263 if intrt==6 & joint==1 & qdate!=1
	replace `var'= `var'/267 if intrt==10 & joint==1 & qdate!=1		
	replace `var'=0 if `var'==.
	}

foreach out in USED /*dep withd*/ bal {
local do ""
*if "`out'"!="withd" local do "replace `out'=. if acct=="J" & qdate==1"
*`do'	
local tit "Share Accts. Used"
	if "`out'"=="dep" local tit "Share Accts. with Deposit"
	if "`out'"=="withd" local tit "Share Accts. with Withdrawal"
	if "`out'"=="bal" local tit "Average Balance"	
	if "`out'"!="bal" local range "0(.05).2"
	if "`out'"=="bal" local range "0(100)400"
	*	if "`out'"!="withd" local range "0(.1).3"
twoway (scatter `out' qdate if joint==0 & intrt==0, connect(direct) lcol(gs0) mcol(gs0)) /// 
	   (scatter `out' qdate if joint==0 & intrt==2, connect(direct) lcol(gs4) mcol(gs4) msym(d)) /// 
	   (scatter `out' qdate if joint==0 & intrt==6, connect(direct) lcol(gs8) mcol(gs8) msym(+)) /// 
	   (scatter `out' qdate if joint==0 & intrt==10, connect(direct) lcol(gs12) mcol(gs12) msym(s)), ///
	   legend(label(1 "0%") label(2 "4%") label(3 "12%") label(4 "20%") row(1) size(small)) xtit("Months Since Account Opening") ytit("`tit'")  /// 
	   xlab(2 "4-6" 4 "10-12" 6 "16-18" 8 "22-24" 10 "28-30" 12 "34-36") ylab(`range') graphregion(color(white) fcolor(white)) /// 
	   tit("i. Individual Accounts", size(medsmall)) name(PA_`out', replace)	   	   
twoway (scatter `out' qdate if acct=="J" & intrt==2, connect(direct) lcol(gs4) mcol(gs4) msym(d)) /// 
	   (scatter `out' qdate if acct=="J" & intrt==6, connect(direct) lcol(gs8) mcol(gs8) msym(+)) (scatter `out' qdate if acct=="J" & intrt==10, connect(direct) lcol(gs12) mcol(gs12) msym(s)), ///
	   legend(label(1 "4%") label(2 "12%") label(3 "20%") row(1) size(small)) xtit("Months Since Account Opening") ytit("`tit'") ylab(`range') ///
	   xlab(2 "4-6" 4 "10-12" 6 "16-18" 8 "22-24" 10 "28-30" 12 "34-36") graphregion(color(white) fcolor(white)) tit("ii. Joint Accounts", size(medsmall)) name(PB_`out', replace)

}	  

grc1leg PA_USED PB_USED, row(1) xsize(10) ysize(5) graphregion(color(white) fcolor(white)) tit("A. Share Accounts Used", size(small)) name(used, replace)  
grc1leg PA_bal PB_bal, row(1) xsize(10) ysize(5) graphregion(color(white) fcolor(white)) tit("B. Average Balance in Accounts", size(small)) name(bal, replace)
grc1leg used bal, row(2) xsize(10) ysize(10) graphregion(color(white) fcolor(white)) name(final, replace)
gr dis final, xsize(10) ysize(10)
gr export "${out_sheet}/_Figures/LongRun_F1_PoolInd_UseByTime.pdf", replace 	

		
* *******************************************************************************
* FIGURE: DISTRIBUTIONAL IMPACTS
* *******************************************************************************
use $ind_final, clear
	set more off
	keep if Eorig==1 & baselineo==0 & round==0
 	local row=1
 		
foreach out in Einc_lastm Etotal_assets E2inc_month {

	mat r_`out'= J(60,15,.)

	local row=1
	forval q=  4(4)96 {
		qreg `out' intrtI intrtI_sp intrtJ $base, q(`q') vce(robust)
			mat r_`out'[`row',1]= _b[intrtI]
			mat r_`out'[`row',2]= _b[intrtI] + _se[intrtI]*1.96
			mat r_`out'[`row',3]= _b[intrtI] - _se[intrtI]*1.96			
			mat r_`out'[`row',4]= _b[intrtI] + _se[intrtI]*1.654
			mat r_`out'[`row',5]= _b[intrtI] - _se[intrtI]*1.654			


			
			mat r_`out'[`row',6]= _b[intrtJ]
			mat r_`out'[`row',7]= _b[intrtJ] + _se[intrtJ]*1.96
			mat r_`out'[`row',8]= _b[intrtJ] - _se[intrtJ]*1.96		
			mat r_`out'[`row',9]= _b[intrtJ] + _se[intrtJ]*1.654
			mat r_`out'[`row',10]= _b[intrtJ] - _se[intrtJ]*1.654		
			
			mat r_`out'[`row',11]= `q'
			_pctile `out' if intrtI==0, p(`q')
				mat r_`out'[`row',12]= r(r1)
			_pctile `out' if intrtJ<.4, p(`q')
				mat r_`out'[`row',13]= r(r1)	
			
		local ++row
		}
		}
	
foreach out in Einc_bus Esave_bus Esave_ba E2profit_month {

	mat r_`out'= J(60,15,.)

	local row=1
	forval q=  50(1)98 {
		qreg `out' intrtI intrtI_sp intrtJ $base, q(`q') vce(robust)
			mat r_`out'[`row',1]= _b[intrtI]
			mat r_`out'[`row',2]= _b[intrtI] + _se[intrtI]*1.96
			mat r_`out'[`row',3]= _b[intrtI] - _se[intrtI]*1.96			
			mat r_`out'[`row',4]= _b[intrtI] + _se[intrtI]*1.654
			mat r_`out'[`row',5]= _b[intrtI] - _se[intrtI]*1.654			


			
			mat r_`out'[`row',6]= _b[intrtJ]
			mat r_`out'[`row',7]= _b[intrtJ] + _se[intrtJ]*1.96
			mat r_`out'[`row',8]= _b[intrtJ] - _se[intrtJ]*1.96		
			mat r_`out'[`row',9]= _b[intrtJ] + _se[intrtJ]*1.654
			mat r_`out'[`row',10]= _b[intrtJ] - _se[intrtJ]*1.654		
			
			mat r_`out'[`row',11]= `q'
			_pctile `out' if intrtI==0, p(`q')
				mat r_`out'[`row',12]= r(r1)
			_pctile `out' if intrtJ<.4, p(`q')
				mat r_`out'[`row',13]= r(r1)	
			
		local ++row
		}
		}
		
	preserve

foreach out in Einc_lastm Etotal_assets Einc_bus Esave_bus E2inc_month {	
	drop _all
		svmat r_`out'
		
		local tit "Monthly Income - Endline 1" 
			if "`out'"=="Etotal_assets" local tit "Total Assets"
			if "`out'"=="E2inc_month" local tit "Monthly Income - Endline 2"
			
			foreach num in 1 2 3 4 5 {
				replace r_`out'`num'= r_`out'`num'/r_`out'12
				}
			foreach num in 6 7 8 9 10 {
				replace r_`out'`num'= r_`out'`num'/r_`out'13
				}
								
			twoway (scatter r_`out'1 r_`out'11, connect(direct) lcol(black) mcol(black)) (rcap r_`out'2 r_`out'3 r_`out'11, lcol(black) mcol(black)) ///
				(rcap r_`out'4 r_`out'5 r_`out'11, lcol(black) mcol(black)), yline(0, lpat(dot) lcol(black)) tit(`tit', size(medsmall))  /// 
				legend(off) xtit("Quantile") ytit("Impact/Control Quantile") graphregion(color(white) fcolor(white)) name(G`out'I, replace)
				
			twoway (scatter r_`out'6 r_`out'11, connect(direct) lcol(black) mcol(black)) (rcap r_`out'7 r_`out'8 r_`out'11, lcol(black) mcol(black)) /// 
				(rcap r_`out'9 r_`out'10 r_`out'11, lcol(black) mcol(black)), yline(0, lpat(dot) lcol(black))  tit(`tit', size(medsmall)) /// 
				legend(off) xtit("Quantile") ytit("Impact/Control Quantile") graphregion(color(white) fcolor(white)) name(G`out'J, replace) 
	
}

foreach out in Einc_bus Esave_bus Esave_ba E2profit_month {	
	drop _all
		svmat r_`out'
			local drop "drop if r_`out'11<75"
		local tit "Business Assets" 
			if "`out'"=="Einc_bus" local tit "Business Profit - Endline 1"
			if "`out'"=="Esave_ba" local tit "Bank Savings"
			if "`out'"=="E2profit_month" {
				local tit "Business Profit - Endline 2"
				local drop "drop if r_`out'11<60"
				}
	`drop'
			foreach num in 1 2 3 4 5 {
				replace r_`out'`num'= r_`out'`num'/r_`out'12
				}
			foreach num in 6 7 8 9 10 {
				replace r_`out'`num'= r_`out'`num'/r_`out'13
				}
								
			twoway (scatter r_`out'1 r_`out'11, connect(direct) lcol(black) mcol(black)) (rcap r_`out'2 r_`out'3 r_`out'11, lcol(black) mcol(black)) ///
				(rcap r_`out'4 r_`out'5 r_`out'11, lcol(black) mcol(black)), yline(0, lpat(dot) lcol(black)) tit(`tit', size(medsmall))  /// 
				legend(off) xtit("Quantile") ytit("Impact/Control Quantile") graphregion(color(white) fcolor(white)) name(G`out'I, replace)
				
			twoway (scatter r_`out'6 r_`out'11, connect(direct) lcol(black) mcol(black)) (rcap r_`out'7 r_`out'8 r_`out'11, lcol(black) mcol(black)) /// 
				(rcap r_`out'9 r_`out'10 r_`out'11, lcol(black) mcol(black)), yline(0, lpat(dot) lcol(black))  tit(`tit', size(medsmall)) /// 
				legend(off) xtit("Quantile") ytit("Impact/Control Quantile") graphregion(color(white) fcolor(white)) name(G`out'J, replace) 			
				
				}
								
	restore
	
* overall outcomes
gr combine GEsave_baI GEtotal_assetsI GEinc_lastmI GE2inc_monthI, row(1) graphregion(color(white) fcolor(white)) title("A. Impact of Individual Interest", size(small)) name(PA, replace) 
	gr combine GEsave_baJ GEtotal_assetsJ GEinc_lastmJ GE2inc_monthJ, row(1) graphregion(color(white) fcolor(white)) title("B. Impact of Joint Interest", size(small))  name(PB, replace) 
gr combine PA PB, graphregion(color(white) fcolor(white)) row(2) xsize(8) ysize(5.5)
	gr export "${out_sheet}/_Figures/LongRun_DistImpactMain.pdf", replace

* business outcomes
gr combine GEsave_busI GEinc_busI GE2profit_monthI, row(1) graphregion(color(white) fcolor(white)) title("A. Impact of Individual Interest", size(small)) name(PC, replace) 
	gr combine GEsave_busJ GEinc_busJ GE2profit_monthJ, row(1) graphregion(color(white) fcolor(white)) title("B. Impact of Joint Interest", size(small))  name(PD, replace) 
gr combine PC PD, graphregion(color(white) fcolor(white)) row(2) xsize(8) ysize(8)
	gr export "${out_sheet}/_Figures/LongRun_DistImpactBus.pdf", replace
	

	
********************************************************
* FIGURE 5: CASH PRIZE VS INTEREST ON BALANCES
********************************************************

* PART 1. BALANCES IN INDIVIDUAL EXPERIMENTAL ACCOUNTS
use "$finaldata/$acctlevel", clear
	replace intrt= intrt/10
g intrtI= intrtIH*ind_h+intrtIW*ind_w if joint==0
g intrtI_sp= intrtIH*ind_w+intrtIW*ind_h if joint==0
	replace intrtI= intrtI/10
	replace intrtI_sp= intrtI_sp/10
	replace intrtJ= intrtJ/10	
g cashprize= cashprize_h*ind_h + cashprize_w*ind_w if joint==0
g cashprize_sp= cashprize_w*ind_h + cashprize_h*ind_w if joint==0

g endbal= bal_6m + intrt*.1*avg_bal_6m*open
g allin = dep_amt_6m + intrt*.1*avg_bal_6m*open

	foreach var in endbal allin avg_bal_6m dep_amt_6m bal_6m {
		replace `var'= `var' - 100
		}
foreach out in endbal allin {
	mat t_`out'=J(100,3,.)
	local k=1
	forval i=75(1)97 {
		local q= `i'/100
		cap qreg `out' intrtI intrtI_sp cashprize_sp intrtJ cashprize if joint==0, q(`q') wlsiter(10)
			_pctile `out', p(`i')
			mat t_`out'[`k',1]= `i'
			mat t_`out'[`k',2]= _b[intrtI] 
			mat t_`out'[`k',3]= _b[cashprize] 
			local ++k
		}
	}	
	

* PART 2. BALANCES IN ALL EXPERIMENTAL ACCOUNTS
collapse (sum) endbal allin (max) intrtIH intrtJ intrtIW cashprize_h cashprize_w, by(ipac)
	g intrtI= (intrtIH + intrtIW)/10
	g cashprize= cashprize_h + cashprize_w
foreach out in endbal allin {
	mat T_`out'=J(100,3,.)
	local k=1
	forval i=75(1)97 {
		local q= `i'/100
		cap qreg `out' intrtI intrtJ cashprize, q(`q') wlsiter(10)
			_pctile `out' if intrtI==0, p(`i')
				local p1=r(r1)
			_pctile `out' if cashprize==0, p(`i')
				local p2=r(r1)
			mat T_`out'[`k',1]= `i'
			mat T_`out'[`k',2]= _b[intrtI] / `p1'
			mat T_`out'[`k',3]= _b[cashprize] / `p1' /* normalize by the same value for comparability */
			local ++k
		}
	}	

	
	
foreach out in endbal allin {
foreach lead in t T {
	if "`out'"=="avg_bal_6m" local tit "Average Daily Balance - 6 Months"
	if "`out'"=="bal_6m" local tit "Ending Balance - 6 Months"
	if "`out'"=="dep_amt_6m" local tit "Total Deposits - 6 Months"	
	if "`out'"=="endbal" & "`lead'"=="t" local tit "i. 6 Month Ending Balance + Interest Payment"
	if "`out'"=="allin" & "`lead'"=="t" local tit "ii. Total Deposits (6 Months) + Interest Payment"
	if "`out'"=="endbal" & "`lead'"=="T" local tit "A. 6 Month Ending Balance + Interest Payment"
	if "`out'"=="allin" & "`lead'"=="T" local tit "B. Total Deposits (6 Months) + Interest Payment"
	
drop _all
svmat `lead'_`out'
sort `lead'_`out'1
twoway (scatter `lead'_`out'2 `lead'_`out'1, connect(direct) lcol(black) mcol(black) msymb(d)) /// 
	(scatter `lead'_`out'3 `lead'_`out'1, connect(direct) lcol(gs8) mcol(gs8) msymb(o)), legend(label(2 "Cash Prize") label(1 "Interest") size(small)) ylab(#4, labsize(small)) xlab(,labsize(small)) ///
	graphregion(color(white) fcolor(white)) ytit("Effect Size/Quantile Value in No Interest Group", size(small)) xtit("Quantile", size(small)) tit("`tit'", size(medsmall)) name(`lead'_`out'I, replace)
}
}

//gr combine t_endbalI t_allinI, col(2) graphregion(color(white) fcolor(white)) xsize(7) ysize(4) name(PA, replace) tit("A. Amount in Individual Experimental Accounts", size(medsmall))
gr combine T_endbalI T_allinI, col(2) graphregion(color(white) fcolor(white)) xsize(7) ysize(4) name(PB, replace) 
			gr export "${out_sheet}/_Figures/LongRun_QuantTmtTotalAcct.pdf", replace


	
* ********************************************************
* FIGURE 5: WHO ARE THE COMPLIERS??
* ********************************************************
set more off
use "$finaldata/$acctlevel", clear
foreach var in avg_bal_6m dep_amt_6m with_amt_6m bal_6m dep_6m withd_6m  {
	fixout `var'	
		ren W`var' W99`var'
	}
keep W99avg_bal_6m W99dep_amt_6m W99with_amt_6m W99bal_6m W99dep_6m W99withd_6m  ipac acct
	reshape wide W99avg_bal_6m W99dep_amt_6m W99with_amt_6m W99bal_6m W99dep_6m W99withd_6m , i(ipac) j(acct) string
		keep ipacou
		tempfile tomerge
			save "`tomerge'"
			
qui do "$dohetfile"
	drop _merge
	merge m:1 ipac using "`tomerge'"
		tab _merge
			drop _merge

local indlist "openI saved_6mI  Wbal_6mI Wdep_amt_6mI INCOME EW99total_assets Eoccup_entre HAS_PROFIT PROFIT EW99netass EW99save_bus E2inflex_bus"
	local indct= wordcount("`indlist'")


coretable3 `indlist' , group(Mresp_avg) cont(base) extra(cashprize cashprize_sp round)
	drop _all
	svmat t
	keep t1-t`indct'
		local i=1
		foreach name in `indlist' {
			ren t`i' `name'
				local ++i
			}
		keep if _n<=12
		g id= round(_n/2,1)
		g coeff= round(_n/2)!=_n/2 
			g high= _n<=6
		reshape wide `indlist', i(id) j(coeff)
			foreach var in `indlist' {
				g `var'LL= `var'1 - 1.96*`var'0
				g `var'UL= `var'1 + 1.96*`var'0
					g `var'll= `var'1 - 1.645*`var'0
					g `var'ul= `var'1 + 1.645*`var'0
				}
			keep if id==1 | id==4
foreach var in `indlist' {
local tit "`var'"
	if "`var'"=="saved_6mI" local tit "Used Acct. - First 6 Months"
	if "`var'"=="openI" local tit "Opened Individual Account"
	if "`var'"=="W99avg_bal_6mI" local tit "Average Daily Balance - First 6 Months"
	if "`var'"=="W99dep_6mI" local tit "Number Deposits - First 6 Months"
	if "`var'"=="W99dep_amt_6mI" local tit "Total Deposits - First 6 Months"
	if "`var'"=="W99saved_6mI" local tit "Used - First 6 Months"
	if "`var'"=="W99bal_6mI" local tit "Balance at 6 Months"
	if "`var'"=="W99total_assets" local tit "Total Assets - Endline 1"
	if "`var'"=="W99netass" local tit "Net Assets - Endline 1"
	if "`var'"=="EW99inc_lastm" local tit "Income Last Month - Endline 1"
	if "`var'"=="Eoccup_entre" local tit "Main Occ. Entrepreneur - Endline 1"
	if "`var'"=="Ehasbusinc" local tit "Operating Business - Endline 1"
	if "`var'"=="EW99save_bus" local tit "Business Assets - Endline 1"
	if "`var'"=="EW99inc_bus" local tit "Business Profit - Endline 1"
	if "`var'"=="E2inflex_bus" local tit "Rigid Business Account - Endline 2"
	if "`var'"=="E2W99profit_month" local tit "Business Profit - Endline 2"	
	if "`var'"=="E2W99inc_month" local tit "Monthly Income - Endline 2"
	if "`var'"=="E2has_profit" local tit "Operating Business - Endline 2"
	if "`var'"=="E2labor_ownb" local tit "Hours Worked On Own Business - Endline 2"
	if "`var'"=="PROFIT" local tit "Business Profit - Pooled Endlines"
	if "`var'"=="INCOME" local tit "Income Last Month - Pooled Endlines"
	if "`var'"=="HAS_PROFIT" local tit "Operating Business - Pooled Endlines"
	
	   
	twoway (bar `var'1 high, barw(.7) bcol(gs7)) (rcap `var'UL `var'LL high, lcol(black) mcol(black)) (rcap `var'ul `var'll high, lcol(black) mcol(black)), xlab(0 "Non-Compliers" 1 "Compliers") legend(off) xtit(" ") /// 
		graphregion(color(white) fcolor(white)) name(`var', replace) title("`tit'", size(medsmall))
	}
		gr combine INCOME Eoccup_entre HAS_PROFIT PROFIT EW99save_bus E2inflex_bus, col(3) row(2)  graphregion(color(white) fcolor(white)) tit("B. Impacts on Long-Run Outcomes", size(small)) name(LongRun_HetCompliersI, replace)
			gr export "${out_sheet}/_Figures/LongRun_HetCompliersI.pdf", replace
		gr combine openI saved_6mI Wbal_6mI Wdep_amt_6mI, col(2) row(2)  graphregion(color(white) fcolor(white))  tit("A. Impacts on Short-Run Outcomes", size(small)) name(LongRun_HetCompliersI_FirstStage, replace)
			gr export "${out_sheet}/_Figures/LongRun_HetCompliersI-FirstStage.pdf", replace		
			


* ********************************************************
* FIGURE 5: INDIVIDUAL VERSUS JOINT INCOME / ASSETS BY INT RATE
* ********************************************************
use $ind_final, clear
	keep if Eorig==1 & round==0
	
		replace intrtI= intrtI*20
		replace intrtJ= intrtJ*20

gr bar EW99inc_lastm_j EW99inc_lastm_r, over(intrtI) stack graphregion(color(white) fcolor(white)) ///
	legend(label(1 "Joint") label(2 "Individual") size(medsmall)) ytit("Income (Ksh)", size(medsmall)) ///
	tit("i. Income Last Month", size(medsmall)) name(PA, replace) bar(1, color(gs5)) bar(2, color(gs10)) ///
	ylab(1500 3000 4500)

gr bar EW99total_assets_j EW99total_assets_r, over(intrtI) stack graphregion(color(white) fcolor(white)) ///
	legend(label(1 "Joint") label(2 "Individual") size(medsmall)) ytit("Income (Ksh)", size(medsmall)) ///
	tit("ii. Total Assets", size(medsmall)) name(PB, replace)  bar(1, color(gs5)) bar(2, color(gs10)) ///
	ylab(10000 20000 30000)

	
gr bar EW99inc_lastm_j EW99inc_lastm_r, over(intrtJ) stack graphregion(color(white) fcolor(white)) ///
	legend(label(1 "Joint") label(2 "Individual") size(medsmall)) ytit("Income (Ksh)", size(medsmall)) ///
	tit("iii. Income Last Month", size(medsmall)) name(PC, replace) bar(1, color(gs5)) bar(2, color(gs10))  ///
	ylab(1500 3000 4500)
gr bar EW99total_assets_j EW99total_assets_r, over(intrtJ) stack graphregion(color(white) fcolor(white)) ///
	legend(label(1 "Joint") label(2 "Individual") size(medsmall)) ytit("Income (Ksh)", size(medsmall)) ///
	tit("iv. Total Assets", size(medsmall)) name(PD, replace)  bar(1, color(gs5)) bar(2, color(gs10)) ///
	ylab(10000 20000 30000)


gr combine PA PB, row(1) tit("A. Effect of the Individual Interest Rate", size(medsmall)) ///
	graphregion(color(white) fcolor(white)) name(p1, replace) xsize(8) ysize(4)

gr combine PC PD, row(1) tit("B. Effect of the Joint Interest Rate", size(medsmall)) ///
	graphregion(color(white) fcolor(white)) name(p2, replace) xsize(8) ysize(4)	
	
gr combine p1 p2, row(2) xsize(8) ysize(8) graphregion(color(white) fcolor(white))

		gr export "${out_sheet}/_Figures/LongRun_IndJointIncAss.pdf", replace


* *************************************************************
* APPENDIX FIGURE D1: WHY EL2 INCOMES ARE SUSPECT
* *************************************************************
set more off
use $ind_final, clear
keep if Eorig==1 & round==0
	replace a11= a11*(52/12)
	replace W99a11= W99a11*(52/12)
	replace W99a11=. if a11_miss==1
twoway (kdensity W99a11, lcol(black)) (kdensity EW99inc_lastm, lcol(gs8)) (kdensity E2W99inc_m, lcol(gs12)) if E2inc_i=="M", /// 
	legend(label(1 "Baseline") label(2 "Endline 1") label(3 "Endline 2") row(1)) xtit("Income - Monthly Basis") ytit("Density") ///
	tit("A. Monthly Reporting", size(medsmall))  graphregion(color(white)) name(PA, replace)

twoway (kdensity W99a11, lcol(black)) (kdensity EW99inc_lastm, lcol(gs8)) (kdensity E2W99inc_m, lcol(gs12)) if E2inc_i=="W", /// 
	 xtit("Income - Monthly Basis") ytit("Density") legend(label(1 "Baseline") label(2 "Endline 1") label(3 "Endline 2") row(1)) ///
	tit("B. Weekly Reporting", size(medsmall))  graphregion(color(white)) name(PB, replace)
	
twoway (kdensity W99a11, lcol(black)) (kdensity EW99inc_lastm, lcol(gs8)) (kdensity E2W99inc_m, lcol(gs12)) if E2inc_i=="D", /// 
	legend(label(1 "Baseline") label(2 "Endline 1") label(3 "Endline 2") row(1)) xtit("Income - Monthly Basis") ytit("Density") ///
	tit("C. Daily Reporting", size(medsmall))  graphregion(color(white)) name(PC, replace)

grc1leg PA PB PC, row(1) graphregion(color(white)) xsize(10) ysize(5) xcommon ycommon name(final, replace)
	gr dis final, xsize(10) ysize(5)
	
	gr export "${out_sheet}/_Figures/LongRun_E2incIssue.pdf", replace

